@@ -9,9 +9,10 @@ from pathlib import Path
 from typing import Optional, Protocol
 
 import humanize
-import rosys
 from PIL import Image, ImageDraw, ImageFont
 
+from .. import rosys
+
 STORAGE_PATH = os.path.expanduser('~/.rosys/timelapse')
 FONT = f'{os.path.dirname(__file__)}/assets/RobotoMono-Medium.ttf'
 IMAGE_FONT = ImageFont.truetype(FONT, 12)
