@@ -1,14 +1,16 @@
 from functools import wraps
-from typing import Optional
 
 from nicegui import ui
 
+from .. import rosys
+
 
 class Track:
 
     def __init__(self) -> None:
         self.stack: list[str] = []
-        self._ui: Optional[ui.label] = None
+        self._labels: list[ui.label] = []
+        rosys.on_repeat(self.update, 0.5)
 
     def __call__(self, f):
         @wraps(f)
@@ -21,17 +23,17 @@ class Track:
                     self.stack.pop()
         return wrap
 
+    def update(self) -> None:
+        for label in self._labels:
+            label.text = ' → '.join(self.stack)
+
     def ui(self) -> ui.label:
-        def update() -> None:
-            self._ui.text = ' → '.join(self.stack)
-        self._ui = ui.label()
-        ui.timer(0.5, update)
-        return self._ui
+        self._labels.append(ui.label())
+        return self._labels[-1]
 
     def reset(self) -> None:
         self.stack.clear()
-        if self._ui:
-            self._ui.text = ''
+        self.update()
 
 
 track = Track()
