@@ -1,5 +1,5 @@
 from .app_controls_ import AppButton
 from .app_controls_ import AppControls as app_controls
-from .automation import Automation
 from .automation_controls_ import AutomationControls as automation_controls
 from .automator import Automator
+from .schedule import Schedule
